[![PyPI version](https://badge.fury.io/py/pylinalg.svg)](https://badge.fury.io/py/pylinalg)

# pylinalg

Linear algebra utilities for Python.

* Zero dependencies
* 95% test coverage
* Adapted from three.js; battle tested and covers common computer graphics problems
